@@ -2,7 +2,9 @@
 #define SOLVER_MMP_H
 
 #include <inttypes.h>
+#include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "constants.h"
 #include "dmumps_c.h"
@@ -48,6 +50,20 @@ struct SolverMMP *new_solver_mmp(int32_t symmetry) {
         return NULL;
     }
 
+    if (strcmp(solver->data.version_number, MUMPS_VERSION) != 0) {
+        printf("\n\n\nERROR: MUMPS LIBRARY VERSION = ");
+        int i;
+        for (i = 0; i < MUMPS_VERSION_MAX_LEN; i++) {
+            printf("%c", solver->data.version_number[i]);
+        }
+        printf(" != INCLUDE VERSION = %s \n\n\n", MUMPS_VERSION);
+        set_mmp_verbose(&solver->data, C_FALSE);
+        solver->data.job = MUMPS_JOB_TERMINATE;
+        dmumps_c(&solver->data);
+        free(solver);
+        return NULL;
+    }
+
     return solver;
 }
 
@@ -78,7 +94,7 @@ int32_t solver_mmp_initialize(struct SolverMMP *solver,
                               int32_t nnz,
                               int32_t const *indices_i,
                               int32_t const *indices_j,
-                              double const *values_a,
+                              double const *values_aij,
                               int32_t ordering,
                               int32_t scaling,
                               int32_t pct_inc_workspace,
@@ -111,7 +127,7 @@ int32_t solver_mmp_initialize(struct SolverMMP *solver,
     for (p = 0; p < nnz; p++) {
         solver->data.irn[p] = indices_i[p] + 1;
         solver->data.jcn[p] = indices_j[p] + 1;
-        solver->data.a[p] = values_a[p];
+        solver->data.a[p] = values_aij[p];
     }
 
     solver->data.n = n;
@@ -161,6 +177,14 @@ int32_t solver_mmp_solve(struct SolverMMP *solver, double *rhs, int32_t verbose)
     return solver->data.INFOG(1);
 }
 
+int32_t solver_mmp_used_ordering(struct SolverMMP *solver) {
+    return solver->data.INFOG(7);
+}
+
+int32_t solver_mmp_used_scaling(struct SolverMMP *solver) {
+    return solver->data.INFOG(33);
+}
+
 #undef INFOG
 #undef ICNTL
 
